@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.1) --
+    -- MAGMA (version 2.6.2) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date July 2021
+       @date April 2022
 */
 
 #ifndef MAGMA_H
@@ -20,8 +20,10 @@
 
 // magma v1 includes cublas.h by default, unless cublas_v2.h has already been included
 #ifndef CUBLAS_V2_H_
+#if defined(MAGMA_HAVE_CUDA)
 #include <cublas.h>
 #endif
+#endif
 
 // Include the MAGMA v2 and v1 APIs,
 // then map names to the v1 API (e.g., magma_zgemm => magma_zgemm_v1).
