@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.1) --
+    -- MAGMA (version 2.6.2) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date July 2021
+       @date April 2022
 */
 
 #ifndef MAGMA_TYPES_H
@@ -182,6 +182,7 @@ typedef double real_Double_t;
      * to turn them into the macro #define s you see below:
      */
     
+    #include <hip/hip_fp16.h>
 
     #ifdef __cplusplus
     extern "C" {
@@ -191,10 +192,10 @@ typedef double real_Double_t;
     struct magma_queue; 
     typedef struct magma_queue* magma_queue_t;
     typedef hipEvent_t  magma_event_t;
-    typedef int         magma_device_t;
+    typedef magma_int_t magma_device_t;
 
     // just define a half precision as a short, since they should be the same byte-size
-    typedef short            magmaHalf;
+    typedef __half            magmaHalf; 
 
     hipStream_t       magma_queue_get_hip_stream      ( magma_queue_t queue );
     hipblasHandle_t   magma_queue_get_hipblas_handle  ( magma_queue_t queue );
@@ -503,7 +504,7 @@ float  magma_cabsf( magmaFloatComplex  x );
 // -----------------------------------------------------------------------------
 #define MAGMA_VERSION_MAJOR 2
 #define MAGMA_VERSION_MINOR 6
-#define MAGMA_VERSION_MICRO 1
+#define MAGMA_VERSION_MICRO 2
 
 // stage is "svn", "beta#", "rc#" (release candidate), or blank ("") for final release
 #define MAGMA_VERSION_STAGE ""
