@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.1) --
+    -- MAGMA (version 2.6.2) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date July 2021
+       @date April 2022
 
        @precisions normal z -> s d c
 */
@@ -319,6 +319,7 @@ magmablas_zgeam(
 
 magma_int_t
 magmablas_zheinertia(
+    magma_uplo_t uplo,
     magma_int_t n,
     magmaDoubleComplex_const_ptr dA, magma_int_t ldda,
     magma_int_t *ipiv,
@@ -1051,9 +1052,8 @@ magma_int_t
 magma_izamax_native(
     magma_int_t length,
     magmaDoubleComplex_ptr x, magma_int_t incx,
-    magma_int_t step,  magma_int_t lda,
     magma_int_t* ipiv, magma_int_t *info,
-    magma_int_t gbstep, magma_queue_t queue);
+    magma_int_t step, magma_int_t gbstep, magma_queue_t queue);
 
 magma_int_t
 magma_izamin(
@@ -1161,9 +1161,9 @@ magma_zdscal(
 
 magma_int_t
 magma_zscal_zgeru_native(
-    magma_int_t m, magma_int_t n, magma_int_t step,
+    magma_int_t m, magma_int_t n,
     magmaDoubleComplex_ptr dA, magma_int_t lda,
-    magma_int_t *info, magma_int_t gbstep,
+    magma_int_t *info, magma_int_t step, magma_int_t gbstep,
     magma_queue_t queue);
 
 void
