@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.1) --
+    -- MAGMA (version 2.6.2) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date July 2021
+       @date April 2022
 
        @author Mark Gates
 
@@ -35,7 +35,7 @@
     const char* g_platform_str = "Xeon Phi";
 
 #elif defined(MAGMA_HAVE_HIP)
-    const char* g_platform_str = "HIP";
+    const char* g_platform_str = "HIPBLAS";
 
 #else
     #error "unknown platform"
