@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.1) --
+    -- MAGMA (version 2.6.2) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date July 2021
+       @date April 2022
 
        @precisions normal z -> c d s
        @author Chongxiao Cao
@@ -80,7 +80,7 @@ int main( int argc, char** argv)
     printf("%% side = %s, uplo = %s, transA = %s, diag = %s \n",
            lapack_side_const(opts.side), lapack_uplo_const(opts.uplo),
            lapack_trans_const(opts.transA), lapack_diag_const(opts.diag) );
-    printf("%% BatchCount   M     N   MAGMA Gflop/s (ms)   CUBLAS Gflop/s (ms)    CPU Gflop/s (ms)      MAGMA     CUBLAS   LAPACK error\n");
+    printf("%% BatchCount   M     N   MAGMA Gflop/s (ms)   %s Gflop/s (ms)    CPU Gflop/s (ms)      MAGMA     %s   LAPACK error\n", g_platform_str, g_platform_str);
     printf("%%=========================================================================================================================\n");
     for( int itest = 0; itest < opts.ntest; ++itest ) {
         for( int iter = 0; iter < opts.niter; ++iter ) {
@@ -221,7 +221,7 @@ int main( int argc, char** argv)
                 int(M), int(N), (const hipblasDoubleComplex*)&alpha,
                 (hipblasDoubleComplex* const*) d_A_array, int(ldda),
                 (      hipblasDoubleComplex**) d_B_array, int(lddb), int(batchCount) );
-            #endif 
+            #endif
 
             cublas_time = magma_sync_wtime( opts.queue ) - cublas_time;
             cublas_perf = gflops / cublas_time;
